==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/FailoverGroupSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs.builder
import com.pulumi.azurenative.azurearcdata.kotlin.enums.FailoverGroupPartnerSyncMode
import com.pulumi.azurenative.azurearcdata.kotlin.enums.InstanceFailoverGroupRole
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The specifications of the failover group resource.
 * @property partnerMI The name of the partner SQL managed instance.
 * @property partnerMirroringCert The mirroring endpoint public certificate for the partner SQL managed instance. Only PEM format is supported.
 * @property partnerMirroringURL The mirroring endpoint URL of the partner SQL managed instance.
 * @property partnerSyncMode The partner sync mode of the SQL managed instance.
 * @property role The role of the SQL managed instance in this failover group.
 * @property sharedName The shared name of the failover group for this SQL managed instance. Both SQL managed instance and its partner have to use the same shared name.
 * @property sourceMI The name of the SQL managed instance with this failover group role.
 */
public data class FailoverGroupSpecArgs(
    public val partnerMI: Output<String>? = null,
    public val partnerMirroringCert: Output<String>? = null,
    public val partnerMirroringURL: Output<String>? = null,
    public val partnerSyncMode: Output<Either<String, FailoverGroupPartnerSyncMode>>? = null,
    public val role: Output<Either<String, InstanceFailoverGroupRole>>,
    public val sharedName: Output<String>? = null,
    public val sourceMI: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs> {
    override fun toJava(): com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs =
        com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs.builder()
            .partnerMI(partnerMI?.applyValue({ args0 -> args0 }))
            .partnerMirroringCert(partnerMirroringCert?.applyValue({ args0 -> args0 }))
            .partnerMirroringURL(partnerMirroringURL?.applyValue({ args0 -> args0 }))
            .partnerSyncMode(
                partnerSyncMode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .role(
                role.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sharedName(sharedName?.applyValue({ args0 -> args0 }))
            .sourceMI(sourceMI?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FailoverGroupSpecArgs].
 */
@PulumiTagMarker
public class FailoverGroupSpecArgsBuilder internal constructor() {
    private var partnerMI: Output<String>? = null

    private var partnerMirroringCert: Output<String>? = null

    private var partnerMirroringURL: Output<String>? = null

    private var partnerSyncMode: Output<Either<String, FailoverGroupPartnerSyncMode>>? = null

    private var role: Output<Either<String, InstanceFailoverGroupRole>>? = null

    private var sharedName: Output<String>? = null

    private var sourceMI: Output<String>? = null

    /**
     * @param value The name of the partner SQL managed instance.
     */
    @JvmName("qhtliaeujovaiquq")
    public suspend fun partnerMI(`value`: Output<String>) {
        this.partnerMI = value
    }

    /**
     * @param value The mirroring endpoint public certificate for the partner SQL managed instance. Only PEM format is supported.
     */
    @JvmName("hlpvvuphxclfkapa")
    public suspend fun partnerMirroringCert(`value`: Output<String>) {
        this.partnerMirroringCert = value
    }

    /**
     * @param value The mirroring endpoint URL of the partner SQL managed instance.
     */
    @JvmName("udasnehcgcjfdmuy")
    public suspend fun partnerMirroringURL(`value`: Output<String>) {
        this.partnerMirroringURL = value
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("wtvtevdcknccxcvw")
    public suspend
    fun partnerSyncMode(`value`: Output<Either<String, FailoverGroupPartnerSyncMode>>) {
        this.partnerSyncMode = value
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("tpsosmjhwxlkwxin")
    public suspend fun role(`value`: Output<Either<String, InstanceFailoverGroupRole>>) {
        this.role = value
    }

    /**
     * @param value The shared name of the failover group for this SQL managed instance. Both SQL managed instance and its partner have to use the same shared name.
     */
    @JvmName("bjmvjoscagxmfddw")
    public suspend fun sharedName(`value`: Output<String>) {
        this.sharedName = value
    }

    /**
     * @param value The name of the SQL managed instance with this failover group role.
     */
    @JvmName("ngnguvbspnfunvck")
    public suspend fun sourceMI(`value`: Output<String>) {
        this.sourceMI = value
    }

    /**
     * @param value The name of the partner SQL managed instance.
     */
    @JvmName("qqyescmqlgqkukrv")
    public suspend fun partnerMI(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerMI = mapped
    }

    /**
     * @param value The mirroring endpoint public certificate for the partner SQL managed instance. Only PEM format is supported.
     */
    @JvmName("yrsxayokjyiksxcu")
    public suspend fun partnerMirroringCert(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerMirroringCert = mapped
    }

    /**
     * @param value The mirroring endpoint URL of the partner SQL managed instance.
     */
    @JvmName("xmikksxdacsifyfd")
    public suspend fun partnerMirroringURL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerMirroringURL = mapped
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("suqijagcmuejmwnj")
    public suspend fun partnerSyncMode(`value`: Either<String, FailoverGroupPartnerSyncMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerSyncMode = mapped
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("vlcmfsjslknllyic")
    public fun partnerSyncMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FailoverGroupPartnerSyncMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.partnerSyncMode = mapped
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("ykkbhfguvamkhywo")
    public fun partnerSyncMode(`value`: FailoverGroupPartnerSyncMode) {
        val toBeMapped = Either.ofRight<String, FailoverGroupPartnerSyncMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.partnerSyncMode = mapped
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("ekncskodccjxumlw")
    public suspend fun role(`value`: Either<String, InstanceFailoverGroupRole>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("adwxdxaaacejkfjp")
    public fun role(`value`: String) {
        val toBeMapped = Either.ofLeft<String, InstanceFailoverGroupRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("otxxmfulrfgrkjrl")
    public fun role(`value`: InstanceFailoverGroupRole) {
        val toBeMapped = Either.ofRight<String, InstanceFailoverGroupRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The shared name of the failover group for this SQL managed instance. Both SQL managed instance and its partner have to use the same shared name.
     */
    @JvmName("objjnkpqqsoewttu")
    public suspend fun sharedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sharedName = mapped
    }

    /**
     * @param value The name of the SQL managed instance with this failover group role.
     */
    @JvmName("binimgxstmhsootn")
    public suspend fun sourceMI(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceMI = mapped
    }

    internal fun build(): FailoverGroupSpecArgs = FailoverGroupSpecArgs(
        partnerMI = partnerMI,
        partnerMirroringCert = partnerMirroringCert,
        partnerMirroringURL = partnerMirroringURL,
        partnerSyncMode = partnerSyncMode,
        role = role ?: throw PulumiNullFieldException("role"),
        sharedName = sharedName,
        sourceMI = sourceMI,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/FailoverGroupSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs.builder
import com.pulumi.azurenative.azurearcdata.kotlin.enums.FailoverGroupPartnerSyncMode
import com.pulumi.azurenative.azurearcdata.kotlin.enums.InstanceFailoverGroupRole
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The specifications of the failover group resource.
 * @property partnerMI The name of the partner SQL managed instance.
 * @property partnerMirroringCert The mirroring endpoint public certificate for the partner SQL managed instance. Only PEM format is supported.
 * @property partnerMirroringURL The mirroring endpoint URL of the partner SQL managed instance.
 * @property partnerSyncMode The partner sync mode of the SQL managed instance.
 * @property role The role of the SQL managed instance in this failover group.
 * @property sharedName The shared name of the failover group for this SQL managed instance. Both SQL managed instance and its partner have to use the same shared name.
 * @property sourceMI The name of the SQL managed instance with this failover group role.
 */
public data class FailoverGroupSpecArgs(
    public val partnerMI: Output<String>? = null,
    public val partnerMirroringCert: Output<String>? = null,
    public val partnerMirroringURL: Output<String>? = null,
    public val partnerSyncMode: Output<Either<String, FailoverGroupPartnerSyncMode>>? = null,
    public val role: Output<Either<String, InstanceFailoverGroupRole>>,
    public val sharedName: Output<String>? = null,
    public val sourceMI: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs> {
    override fun toJava(): com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs =
        com.pulumi.azurenative.azurearcdata.inputs.FailoverGroupSpecArgs.builder()
            .partnerMI(partnerMI?.applyValue({ args0 -> args0 }))
            .partnerMirroringCert(partnerMirroringCert?.applyValue({ args0 -> args0 }))
            .partnerMirroringURL(partnerMirroringURL?.applyValue({ args0 -> args0 }))
            .partnerSyncMode(
                partnerSyncMode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .role(
                role.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sharedName(sharedName?.applyValue({ args0 -> args0 }))
            .sourceMI(sourceMI?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FailoverGroupSpecArgs].
 */
@PulumiTagMarker
public class FailoverGroupSpecArgsBuilder internal constructor() {
    private var partnerMI: Output<String>? = null

    private var partnerMirroringCert: Output<String>? = null

    private var partnerMirroringURL: Output<String>? = null

    private var partnerSyncMode: Output<Either<String, FailoverGroupPartnerSyncMode>>? = null

    private var role: Output<Either<String, InstanceFailoverGroupRole>>? = null

    private var sharedName: Output<String>? = null

    private var sourceMI: Output<String>? = null

    /**
     * @param value The name of the partner SQL managed instance.
     */
    @JvmName("yjfxxbfquktxpjbh")
    public suspend fun partnerMI(`value`: Output<String>) {
        this.partnerMI = value
    }

    /**
     * @param value The mirroring endpoint public certificate for the partner SQL managed instance. Only PEM format is supported.
     */
    @JvmName("mrjppgsasuashpmy")
    public suspend fun partnerMirroringCert(`value`: Output<String>) {
        this.partnerMirroringCert = value
    }

    /**
     * @param value The mirroring endpoint URL of the partner SQL managed instance.
     */
    @JvmName("cxnoggurjbvlbxeb")
    public suspend fun partnerMirroringURL(`value`: Output<String>) {
        this.partnerMirroringURL = value
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("ecigjtmuxncdwquc")
    public suspend
    fun partnerSyncMode(`value`: Output<Either<String, FailoverGroupPartnerSyncMode>>) {
        this.partnerSyncMode = value
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("nyswyepsplibalru")
    public suspend fun role(`value`: Output<Either<String, InstanceFailoverGroupRole>>) {
        this.role = value
    }

    /**
     * @param value The shared name of the failover group for this SQL managed instance. Both SQL managed instance and its partner have to use the same shared name.
     */
    @JvmName("pqwtitkmqvjwleuq")
    public suspend fun sharedName(`value`: Output<String>) {
        this.sharedName = value
    }

    /**
     * @param value The name of the SQL managed instance with this failover group role.
     */
    @JvmName("wjxfyfcvhiubasvs")
    public suspend fun sourceMI(`value`: Output<String>) {
        this.sourceMI = value
    }

    /**
     * @param value The name of the partner SQL managed instance.
     */
    @JvmName("itjlvdcbflujccal")
    public suspend fun partnerMI(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerMI = mapped
    }

    /**
     * @param value The mirroring endpoint public certificate for the partner SQL managed instance. Only PEM format is supported.
     */
    @JvmName("ckrtudnwpvkepvvo")
    public suspend fun partnerMirroringCert(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerMirroringCert = mapped
    }

    /**
     * @param value The mirroring endpoint URL of the partner SQL managed instance.
     */
    @JvmName("cxphjtqwjfaecrba")
    public suspend fun partnerMirroringURL(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerMirroringURL = mapped
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("ahbdhhllxvghyvsx")
    public suspend fun partnerSyncMode(`value`: Either<String, FailoverGroupPartnerSyncMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partnerSyncMode = mapped
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("tsfatdepsmiikiyq")
    public fun partnerSyncMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FailoverGroupPartnerSyncMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.partnerSyncMode = mapped
    }

    /**
     * @param value The partner sync mode of the SQL managed instance.
     */
    @JvmName("xjxsckwukqseyefd")
    public fun partnerSyncMode(`value`: FailoverGroupPartnerSyncMode) {
        val toBeMapped = Either.ofRight<String, FailoverGroupPartnerSyncMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.partnerSyncMode = mapped
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("vwrwktofpaxrtefa")
    public suspend fun role(`value`: Either<String, InstanceFailoverGroupRole>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("svajkjfhygmurvux")
    public fun role(`value`: String) {
        val toBeMapped = Either.ofLeft<String, InstanceFailoverGroupRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The role of the SQL managed instance in this failover group.
     */
    @JvmName("rxdaahhyrritnxtv")
    public fun role(`value`: InstanceFailoverGroupRole) {
        val toBeMapped = Either.ofRight<String, InstanceFailoverGroupRole>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value The shared name of the failover group for this SQL managed instance. Both SQL managed instance and its partner have to use the same shared name.
     */
    @JvmName("wswbhwpudjawbvhw")
    public suspend fun sharedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sharedName = mapped
    }

    /**
     * @param value The name of the SQL managed instance with this failover group role.
     */
    @JvmName("qvjchgnqkjpxhejb")
    public suspend fun sourceMI(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceMI = mapped
    }

    internal fun build(): FailoverGroupSpecArgs = FailoverGroupSpecArgs(
        partnerMI = partnerMI,
        partnerMirroringCert = partnerMirroringCert,
        partnerMirroringURL = partnerMirroringURL,
        partnerSyncMode = partnerSyncMode,
        role = role ?: throw PulumiNullFieldException("role"),
        sharedName = sharedName,
        sourceMI = sourceMI,
    )
}
